# MirAIe API for Python

# Medium multiply

A small demo library for a Medium publication about publishing libraries.

### Installation

```
pip install miraie-ac
```

### Get started

```Python
from miraie-ac import MirAIeHub, MirAIeBroker

# Instantiate a MirAIeHub object
broker = MirAIeBroker()

# Instantiate a MirAIeHub object
hub = MirAIeHub()

# Intialize the hub (+91xxxxxxxxxx, password, broker)
hub.init(mobile, password, broker)
```
